//
//      Yasuharu Okamoto,  2021.12
//
data {
    int NB;
    int kB;
    int NC;
    int kC;
    int NBC;
    int kBC;    
}
parameters {
    real fB;     //   factor for B
    real fC;     //   factor for C
    real fBC;    //   interaction factor of B and C
}
transformed parameters {
    real<lower = 0.0, upper = 1.0> PdB;
    real<lower = 0.0, upper = 1.0> PdC;
    real<lower = 0.0, upper = 1.0> PdBC;
    real<lower = 0.0, upper = 1.0> PcB;
    real<lower = 0.0, upper = 1.0> PcC;
    real<lower = 0.0, upper = 1.0> PcBC;
    //
    //      Logistic regression model
    //
    PdB = 1.0 / (1.0 + exp(-fB));
    PdC = 1.0 / (1.0 + exp(-fC));
    PdBC = 1.0 / (1.0 + exp(-(fB + fC + fBC)));
    
    PcB = PdB + (1.0 - PdB) * (1.0 / 3.0);
    PcC = PdC + (1.0 - PdC) * (1.0 / 3.0);
    PcBC = PdBC + (1.0 - PdBC) * (1.0 / 3.0); 
}
model {
    //
    //    Weakly informative priors
    //
    fB ~ normal(0.0, 5.0);
    fC ~ normal(0.0, 5.0);
    fBC ~ normal(0.0, 5.0);
    //
    //    Distributions of the correct responses
    //
    kB ~ binomial(NB, PcB);
    kC ~ binomial(NC, PcC);
    kBC ~ binomial(NBC, PcBC);
}
